@@ -139,6 +139,8 @@ pub struct EmitterWriter {
     short_message: bool,
     teach: bool,
     ui_testing: bool,
+
+    skip_filename: bool,
 }
 
 struct FileWithAnnotatedLines {
@@ -162,6 +164,7 @@ impl EmitterWriter {
             short_message,
             teach,
             ui_testing: false,
+            skip_filename: false,
         }
     }
 }
@@ -179,6 +182,7 @@ impl EmitterWriter {
             short_message,
             teach,
             ui_testing: false,
+            skip_filename: false,
         }
     }
 
@@ -187,6 +191,11 @@ impl EmitterWriter {
         self
     }
 
+    pub fn skip_filename(mut self, skip_filename: bool) -> Self {
+        self.skip_filename = skip_filename;
+        self
+    }
+
     fn maybe_anonymized(&self, line_num: usize) -> String {
         if self.ui_testing {
             ANONYMIZED_LINE_NUM.to_string()
@@ -526,7 +535,7 @@ impl EmitterWriter {
                                                      // or the next are vertical line placeholders.
                         || (annotation.takes_space() // If either this or the next annotation is
                             && next.has_label())     // multiline start/end, move it to a new line
-                        || (annotation.has_label()   // so as not to overlap the orizontal lines.
+                        || (annotation.has_label()   // so as not to overlap the horizontal lines.
                             && next.takes_space())
                         || (annotation.takes_space() && next.takes_space())
                         || (overlaps(next, annotation, l)
@@ -556,7 +565,7 @@ impl EmitterWriter {
             return vec![];
         }
 
-        // Write the colunmn separator.
+        // Write the column separator.
         //
         // After this we will have:
         //
@@ -1011,17 +1020,21 @@ impl EmitterWriter {
                     // remember where we are in the output buffer for easy reference
                     let buffer_msg_line_offset = buffer.num_lines();
 
-                    buffer.prepend(buffer_msg_line_offset, "--> ", Style::LineNumber);
-                    buffer.append(
-                        buffer_msg_line_offset,
-                        &format!(
-                            "{}:{}:{}",
-                            loc.file.name,
-                            sm.doctest_offset_line(loc.line),
-                            loc.col.0 + 1
-                        ),
-                        Style::LineAndColumn,
-                    );
+                    if !self.skip_filename {
+                        buffer.prepend(buffer_msg_line_offset, "--> ", Style::LineNumber);
+
+                        buffer.append(
+                            buffer_msg_line_offset,
+                            &format!(
+                                "{}:{}:{}",
+                                loc.file.name,
+                                sm.doctest_offset_line(loc.line),
+                                loc.col.0 + 1
+                            ),
+                            Style::LineAndColumn,
+                        );
+                    }
+
                     for _ in 0..max_line_num_len {
                         buffer.prepend(buffer_msg_line_offset, " ", Style::NoStyle);
                     }
